@@ -60,8 +60,8 @@ public:
 };
 
 // Register class for serialization
-CEREAL_REGISTER_TYPE(SGD);
-CEREAL_REGISTER_POLYMORPHIC_RELATION(Optimizer, SGD);
+CEREAL_REGISTER_TYPE(SGD)
+CEREAL_REGISTER_POLYMORPHIC_RELATION(Optimizer, SGD)
 
 // ---------------------------------------------------------------------------//
 // RMSprop optimizer
@@ -101,8 +101,8 @@ public:
 };
 
 // Register class for serialization
-CEREAL_REGISTER_TYPE(RMSprop);
-CEREAL_REGISTER_POLYMORPHIC_RELATION(Optimizer, RMSprop);
+CEREAL_REGISTER_TYPE(RMSprop)
+CEREAL_REGISTER_POLYMORPHIC_RELATION(Optimizer, RMSprop)
 
 // ---------------------------------------------------------------------------//
 // Adam optimizer
@@ -147,8 +147,8 @@ public:
 };
 
 // Register class for serialization
-CEREAL_REGISTER_TYPE(Adam);
-CEREAL_REGISTER_POLYMORPHIC_RELATION(Optimizer, Adam);
+CEREAL_REGISTER_TYPE(Adam)
+CEREAL_REGISTER_POLYMORPHIC_RELATION(Optimizer, Adam)
 
 // ---------------------------------------------------------------------------//
 // Optimizer factory 
